package com.luck.picture.lib.io;

import android.util.Log;
import f0.h;
import java.util.HashMap;
import java.util.Map;
import java.util.NavigableMap;
import java.util.TreeMap;

public final class LruArrayPool implements ArrayPool {
    public static final int DEFAULT_SIZE = 4194304;
    static final int MAX_OVER_SIZE_MULTIPLE = 8;
    private static final int SINGLE_ARRAY_MAX_SIZE_DIVISOR = 2;
    private final Map<Class<?>, ArrayAdapterInterface<?>> adapters;
    private int currentSize;
    private final GroupedLinkedMap<Key, Object> groupedMap;
    private final KeyPool keyPool;
    private final int maxSize;
    private final Map<Class<?>, NavigableMap<Integer, Integer>> sortedSizes;

    /* access modifiers changed from: private */
    public static final class Key implements PoolAble {
        private Class<?> arrayClass;
        private final KeyPool pool;
        int size;

        Key(KeyPool keyPool) {
            this.pool = keyPool;
        }

        public boolean equals(Object obj) {
            if (!(obj instanceof Key)) {
                return false;
            }
            Key key = (Key) obj;
            return this.size == key.size && this.arrayClass == key.arrayClass;
        }

        public int hashCode() {
            int i5 = this.size * 31;
            Class<?> cls = this.arrayClass;
            return i5 + (cls != null ? cls.hashCode() : 0);
        }

        /* access modifiers changed from: package-private */
        public void init(int i5, Class<?> cls) {
            this.size = i5;
            this.arrayClass = cls;
        }

        @Override // com.luck.picture.lib.io.PoolAble
        public void offer() {
            this.pool.offer(this);
        }

        public String toString() {
            return "Key{size=" + this.size + "array=" + this.arrayClass + '}';
        }
    }

    /* access modifiers changed from: private */
    public static final class KeyPool extends BaseKeyPool<Key> {
        KeyPool() {
        }

        /* access modifiers changed from: protected */
        @Override // com.luck.picture.lib.io.BaseKeyPool
        public Key create() {
            return new Key(this);
        }

        /* access modifiers changed from: package-private */
        public Key get(int i5, Class<?> cls) {
            Key key = (Key) get();
            key.init(i5, cls);
            return key;
        }
    }

    public LruArrayPool() {
        this.groupedMap = new GroupedLinkedMap<>();
        this.keyPool = new KeyPool();
        this.sortedSizes = new HashMap();
        this.adapters = new HashMap();
        this.maxSize = DEFAULT_SIZE;
    }

    public LruArrayPool(int i5) {
        this.groupedMap = new GroupedLinkedMap<>();
        this.keyPool = new KeyPool();
        this.sortedSizes = new HashMap();
        this.adapters = new HashMap();
        this.maxSize = i5;
    }

    private void decrementArrayOfSize(int i5, Class<?> cls) {
        NavigableMap<Integer, Integer> sizesForAdapter = getSizesForAdapter(cls);
        Integer num = (Integer) sizesForAdapter.get(Integer.valueOf(i5));
        if (num != null) {
            int intValue = num.intValue();
            Integer valueOf = Integer.valueOf(i5);
            if (intValue == 1) {
                sizesForAdapter.remove(valueOf);
            } else {
                sizesForAdapter.put(valueOf, Integer.valueOf(num.intValue() - 1));
            }
        } else {
            throw new NullPointerException("Tried to decrement empty size, size: " + i5 + ", this: " + this);
        }
    }

    private void evict() {
        evictToSize(this.maxSize);
    }

    private void evictToSize(int i5) {
        while (this.currentSize > i5) {
            Object removeLast = this.groupedMap.removeLast();
            h.g(removeLast);
            ArrayAdapterInterface adapterFromObject = getAdapterFromObject(removeLast);
            this.currentSize -= adapterFromObject.getArrayLength(removeLast) * adapterFromObject.getElementSizeInBytes();
            decrementArrayOfSize(adapterFromObject.getArrayLength(removeLast), removeLast.getClass());
            if (Log.isLoggable(adapterFromObject.getTag(), 2)) {
                Log.v(adapterFromObject.getTag(), "evicted: " + adapterFromObject.getArrayLength(removeLast));
            }
        }
    }

    private <T> ArrayAdapterInterface<T> getAdapterFromObject(T t5) {
        return getAdapterFromType(t5.getClass());
    }

    private <T> ArrayAdapterInterface<T> getAdapterFromType(Class<T> cls) {
        ByteArrayAdapter byteArrayAdapter = (ArrayAdapterInterface<T>) this.adapters.get(cls);
        if (byteArrayAdapter == null) {
            if (cls.equals(int[].class)) {
                byteArrayAdapter = new IntegerArrayAdapter();
            } else if (cls.equals(byte[].class)) {
                byteArrayAdapter = new ByteArrayAdapter();
            } else {
                throw new IllegalArgumentException("No array pool found for: " + cls.getSimpleName());
            }
            this.adapters.put(cls, byteArrayAdapter);
        }
        return byteArrayAdapter;
    }

    private <T> T getArrayForKey(Key key) {
        return (T) this.groupedMap.get(key);
    }

    private <T> T getForKey(Key key, Class<T> cls) {
        ArrayAdapterInterface<T> adapterFromType = getAdapterFromType(cls);
        T t5 = (T) getArrayForKey(key);
        if (t5 != null) {
            this.currentSize -= adapterFromType.getArrayLength(t5) * adapterFromType.getElementSizeInBytes();
            decrementArrayOfSize(adapterFromType.getArrayLength(t5), cls);
        }
        if (t5 != null) {
            return t5;
        }
        if (Log.isLoggable(adapterFromType.getTag(), 2)) {
            Log.v(adapterFromType.getTag(), "Allocated " + key.size + " bytes");
        }
        return adapterFromType.newArray(key.size);
    }

    private NavigableMap<Integer, Integer> getSizesForAdapter(Class<?> cls) {
        NavigableMap<Integer, Integer> navigableMap = this.sortedSizes.get(cls);
        if (navigableMap != null) {
            return navigableMap;
        }
        TreeMap treeMap = new TreeMap();
        this.sortedSizes.put(cls, treeMap);
        return treeMap;
    }

    private boolean isNoMoreThanHalfFull() {
        int i5 = this.currentSize;
        return i5 == 0 || this.maxSize / i5 >= 2;
    }

    private boolean isSmallEnoughForReuse(int i5) {
        return i5 <= this.maxSize / 2;
    }

    private boolean mayFillRequest(int i5, Integer num) {
        return num != null && (isNoMoreThanHalfFull() || num.intValue() <= i5 * 8);
    }

    @Override // com.luck.picture.lib.io.ArrayPool
    public synchronized void clearMemory() {
        evictToSize(0);
    }

    @Override // com.luck.picture.lib.io.ArrayPool
    public synchronized <T> T get(int i5, Class<T> cls) {
        Integer ceilingKey;
        ceilingKey = getSizesForAdapter(cls).ceilingKey(Integer.valueOf(i5));
        return (T) getForKey(mayFillRequest(i5, ceilingKey) ? this.keyPool.get(ceilingKey.intValue(), cls) : this.keyPool.get(i5, cls), cls);
    }

    /* access modifiers changed from: package-private */
    public int getCurrentSize() {
        int i5 = 0;
        for (Class<?> cls : this.sortedSizes.keySet()) {
            for (Integer num : this.sortedSizes.get(cls).keySet()) {
                i5 += num.intValue() * ((Integer) this.sortedSizes.get(cls).get(num)).intValue() * getAdapterFromType(cls).getElementSizeInBytes();
            }
        }
        return i5;
    }

    @Override // com.luck.picture.lib.io.ArrayPool
    public synchronized <T> void put(T t5) {
        Class<?> cls = t5.getClass();
        ArrayAdapterInterface<T> adapterFromType = getAdapterFromType(cls);
        int arrayLength = adapterFromType.getArrayLength(t5);
        int elementSizeInBytes = adapterFromType.getElementSizeInBytes() * arrayLength;
        if (isSmallEnoughForReuse(elementSizeInBytes)) {
            Key key = this.keyPool.get(arrayLength, cls);
            this.groupedMap.put(key, t5);
            NavigableMap<Integer, Integer> sizesForAdapter = getSizesForAdapter(cls);
            Integer num = (Integer) sizesForAdapter.get(Integer.valueOf(key.size));
            Integer valueOf = Integer.valueOf(key.size);
            int i5 = 1;
            if (num != null) {
                i5 = 1 + num.intValue();
            }
            sizesForAdapter.put(valueOf, Integer.valueOf(i5));
            this.currentSize += elementSizeInBytes;
            evict();
        }
    }

    @Override // com.luck.picture.lib.io.ArrayPool
    @Deprecated
    public <T> void put(T t5, Class<T> cls) {
        put(t5);
    }
}
