package com.yalantis.ucrop.util;

import android.text.TextUtils;
import android.util.Log;
import androidx.exifinterface.media.a;
import java.io.IOException;
import java.io.InputStream;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.nio.charset.StandardCharsets;

public class ImageHeaderParser {
    private static final int[] BYTES_PER_FORMAT = {0, 1, 1, 2, 4, 8, 1, 1, 2, 4, 8, 4, 8};
    private static final int EXIF_MAGIC_NUMBER = 65496;
    private static final int EXIF_SEGMENT_TYPE = 225;
    private static final int INTEL_TIFF_MAGIC_NUMBER = 18761;
    private static final String JPEG_EXIF_SEGMENT_PREAMBLE = "Exif\u0000\u0000";
    private static final byte[] JPEG_EXIF_SEGMENT_PREAMBLE_BYTES = JPEG_EXIF_SEGMENT_PREAMBLE.getBytes(StandardCharsets.UTF_8);
    private static final int MARKER_EOI = 217;
    private static final int MOTOROLA_TIFF_MAGIC_NUMBER = 19789;
    private static final int ORIENTATION_TAG_TYPE = 274;
    private static final int SEGMENT_SOS = 218;
    private static final int SEGMENT_START_ID = 255;
    private static final String TAG = "ImageHeaderParser";
    public static final int UNKNOWN_ORIENTATION = -1;
    private final Reader reader;

    /* access modifiers changed from: private */
    public static class RandomAccessReader {
        private final ByteBuffer data;

        public RandomAccessReader(byte[] bArr, int i5) {
            this.data = (ByteBuffer) ByteBuffer.wrap(bArr).order(ByteOrder.BIG_ENDIAN).limit(i5);
        }

        public short getInt16(int i5) {
            return this.data.getShort(i5);
        }

        public int getInt32(int i5) {
            return this.data.getInt(i5);
        }

        public int length() {
            return this.data.remaining();
        }

        public void order(ByteOrder byteOrder) {
            this.data.order(byteOrder);
        }
    }

    /* access modifiers changed from: private */
    public interface Reader {
        int getUInt16();

        short getUInt8();

        int read(byte[] bArr, int i5);

        long skip(long j5);
    }

    private static class StreamReader implements Reader {
        private final InputStream is;

        public StreamReader(InputStream inputStream) {
            this.is = inputStream;
        }

        @Override // com.yalantis.ucrop.util.ImageHeaderParser.Reader
        public int getUInt16() {
            return ((this.is.read() << 8) & 65280) | (this.is.read() & ImageHeaderParser.SEGMENT_START_ID);
        }

        @Override // com.yalantis.ucrop.util.ImageHeaderParser.Reader
        public short getUInt8() {
            return (short) (this.is.read() & ImageHeaderParser.SEGMENT_START_ID);
        }

        @Override // com.yalantis.ucrop.util.ImageHeaderParser.Reader
        public int read(byte[] bArr, int i5) {
            int i6 = i5;
            while (i6 > 0) {
                int read = this.is.read(bArr, i5 - i6, i6);
                if (read == -1) {
                    break;
                }
                i6 -= read;
            }
            return i5 - i6;
        }

        @Override // com.yalantis.ucrop.util.ImageHeaderParser.Reader
        public long skip(long j5) {
            if (j5 < 0) {
                return 0;
            }
            long j6 = j5;
            while (j6 > 0) {
                long skip = this.is.skip(j6);
                if (skip <= 0) {
                    if (this.is.read() == -1) {
                        break;
                    }
                    skip = 1;
                }
                j6 -= skip;
            }
            return j5 - j6;
        }
    }

    public ImageHeaderParser(InputStream inputStream) {
        this.reader = new StreamReader(inputStream);
    }

    private static int calcTagOffset(int i5, int i6) {
        return i5 + 2 + (i6 * 12);
    }

    public static void copyExif(a aVar, int i5, int i6, String str) {
        String[] strArr = {"FNumber", "DateTime", "DateTimeDigitized", "ExposureTime", "Flash", "FocalLength", "GPSAltitude", "GPSAltitudeRef", "GPSDateStamp", "GPSLatitude", "GPSLatitudeRef", "GPSLongitude", "GPSLongitudeRef", "GPSProcessingMethod", "GPSTimeStamp", "PhotographicSensitivity", "Make", "Model", "SubSecTime", "SubSecTimeDigitized", "SubSecTimeOriginal", "WhiteBalance"};
        try {
            a aVar2 = new a(str);
            for (int i7 = 0; i7 < 22; i7++) {
                String str2 = strArr[i7];
                String g5 = aVar.g(str2);
                if (!TextUtils.isEmpty(g5)) {
                    aVar2.b0(str2, g5);
                }
            }
            aVar2.b0("ImageWidth", String.valueOf(i5));
            aVar2.b0("ImageLength", String.valueOf(i6));
            aVar2.b0("Orientation", "0");
            aVar2.W();
        } catch (IOException e5) {
            Log.d(TAG, e5.getMessage());
        }
    }

    private static boolean handles(int i5) {
        return (i5 & EXIF_MAGIC_NUMBER) == EXIF_MAGIC_NUMBER || i5 == MOTOROLA_TIFF_MAGIC_NUMBER || i5 == INTEL_TIFF_MAGIC_NUMBER;
    }

    private boolean hasJpegExifPreamble(byte[] bArr, int i5) {
        boolean z4 = bArr != null && i5 > JPEG_EXIF_SEGMENT_PREAMBLE_BYTES.length;
        if (z4) {
            int i6 = 0;
            while (true) {
                byte[] bArr2 = JPEG_EXIF_SEGMENT_PREAMBLE_BYTES;
                if (i6 >= bArr2.length) {
                    break;
                } else if (bArr[i6] != bArr2[i6]) {
                    return false;
                } else {
                    i6++;
                }
            }
        }
        return z4;
    }

    private int moveToExifSegmentAndGetLength() {
        short uInt8;
        int uInt16;
        long j5;
        long skip;
        do {
            short uInt82 = this.reader.getUInt8();
            if (uInt82 != SEGMENT_START_ID) {
                if (Log.isLoggable(TAG, 3)) {
                    Log.d(TAG, "Unknown segmentId=" + ((int) uInt82));
                }
                return -1;
            }
            uInt8 = this.reader.getUInt8();
            if (uInt8 == SEGMENT_SOS) {
                return -1;
            }
            if (uInt8 == MARKER_EOI) {
                if (Log.isLoggable(TAG, 3)) {
                    Log.d(TAG, "Found MARKER_EOI in exif segment");
                }
                return -1;
            }
            uInt16 = this.reader.getUInt16() - 2;
            if (uInt8 == EXIF_SEGMENT_TYPE) {
                return uInt16;
            }
            j5 = (long) uInt16;
            skip = this.reader.skip(j5);
        } while (skip == j5);
        if (Log.isLoggable(TAG, 3)) {
            Log.d(TAG, "Unable to skip enough data, type: " + ((int) uInt8) + ", wanted to skip: " + uInt16 + ", but actually skipped: " + skip);
        }
        return -1;
    }

    /* JADX WARNING: Removed duplicated region for block: B:11:0x0042  */
    private static int parseExifSegment(RandomAccessReader randomAccessReader) {
        ByteOrder byteOrder;
        short int16;
        int i5;
        String str;
        StringBuilder sb;
        String str2;
        short int162 = randomAccessReader.getInt16(6);
        if (int162 != MOTOROLA_TIFF_MAGIC_NUMBER) {
            if (int162 == INTEL_TIFF_MAGIC_NUMBER) {
                byteOrder = ByteOrder.LITTLE_ENDIAN;
                randomAccessReader.order(byteOrder);
                int int32 = randomAccessReader.getInt32(10) + 6;
                int16 = randomAccessReader.getInt16(int32);
                for (i5 = 0; i5 < int16; i5++) {
                    int calcTagOffset = calcTagOffset(int32, i5);
                    short int163 = randomAccessReader.getInt16(calcTagOffset);
                    if (int163 == ORIENTATION_TAG_TYPE) {
                        short int164 = randomAccessReader.getInt16(calcTagOffset + 2);
                        if (int164 >= 1 && int164 <= 12) {
                            int int322 = randomAccessReader.getInt32(calcTagOffset + 4);
                            if (int322 >= 0) {
                                if (Log.isLoggable(TAG, 3)) {
                                    Log.d(TAG, "Got tagIndex=" + i5 + " tagType=" + ((int) int163) + " formatCode=" + ((int) int164) + " componentCount=" + int322);
                                }
                                int i6 = int322 + BYTES_PER_FORMAT[int164];
                                if (i6 <= 4) {
                                    int i7 = calcTagOffset + 8;
                                    if (i7 < 0 || i7 > randomAccessReader.length()) {
                                        if (Log.isLoggable(TAG, 3)) {
                                            str = "Illegal tagValueOffset=" + i7 + " tagType=" + ((int) int163);
                                            Log.d(TAG, str);
                                        }
                                    } else if (i6 >= 0 && i6 + i7 <= randomAccessReader.length()) {
                                        return randomAccessReader.getInt16(i7);
                                    } else {
                                        if (Log.isLoggable(TAG, 3)) {
                                            sb = new StringBuilder();
                                            sb.append("Illegal number of bytes for TI tag data tagType=");
                                            sb.append((int) int163);
                                            str = sb.toString();
                                            Log.d(TAG, str);
                                        }
                                    }
                                } else if (Log.isLoggable(TAG, 3)) {
                                    sb = new StringBuilder();
                                    str2 = "Got byte count > 4, not orientation, continuing, formatCode=";
                                }
                            } else if (Log.isLoggable(TAG, 3)) {
                                str = "Negative tiff component count";
                                Log.d(TAG, str);
                            }
                        } else if (Log.isLoggable(TAG, 3)) {
                            sb = new StringBuilder();
                            str2 = "Got invalid format code = ";
                        }
                        sb.append(str2);
                        sb.append((int) int164);
                        str = sb.toString();
                        Log.d(TAG, str);
                    }
                }
                return -1;
            } else if (Log.isLoggable(TAG, 3)) {
                Log.d(TAG, "Unknown endianness = " + ((int) int162));
            }
        }
        byteOrder = ByteOrder.BIG_ENDIAN;
        randomAccessReader.order(byteOrder);
        int int323 = randomAccessReader.getInt32(10) + 6;
        int16 = randomAccessReader.getInt16(int323);
        while (i5 < int16) {
        }
        return -1;
    }

    private int parseExifSegment(byte[] bArr, int i5) {
        int read = this.reader.read(bArr, i5);
        if (read != i5) {
            if (Log.isLoggable(TAG, 3)) {
                Log.d(TAG, "Unable to read exif segment data, length: " + i5 + ", actually read: " + read);
            }
            return -1;
        } else if (hasJpegExifPreamble(bArr, i5)) {
            return parseExifSegment(new RandomAccessReader(bArr, i5));
        } else {
            if (Log.isLoggable(TAG, 3)) {
                Log.d(TAG, "Missing jpeg exif preamble");
            }
            return -1;
        }
    }

    public int getOrientation() {
        int uInt16 = this.reader.getUInt16();
        if (!handles(uInt16)) {
            if (Log.isLoggable(TAG, 3)) {
                Log.d(TAG, "Parser doesn't handle magic number: " + uInt16);
            }
            return -1;
        }
        int moveToExifSegmentAndGetLength = moveToExifSegmentAndGetLength();
        if (moveToExifSegmentAndGetLength != -1) {
            return parseExifSegment(new byte[moveToExifSegmentAndGetLength], moveToExifSegmentAndGetLength);
        }
        if (Log.isLoggable(TAG, 3)) {
            Log.d(TAG, "Failed to parse exif segment length, or exif segment not found");
        }
        return -1;
    }
}
